function [ A ] = lds_r( n,m )
%
% Output matrix containing the local deterministic strategies where 0-0
% measurement is 0 (the top left one)
%
% INPUT
% n: number of possible measurement settings on both sides
% m: number of possible outcomes per measurement
%
% OUTPUT
% A: ( (n*m)^2 x m^2n) matrix with local deterministic strategies in columns
%
% NOTE
% only works for m = 2!
%

if (m ~= 2)
    error('Not supported yet!');
end

% total number of local strategies (for each party)
t = m^n;

% counters
r = 1;

A = zeros((n*m)^2,2*(2^n)-1);

% allocate strategie vectors now
a = zeros(n,1);
% b = ones(n,1);

r_b = 2;

for i = 1:t
    % the behaviour as matrix
    S = zeros(n*m,n*m);
    
    % go over all measurement setups
    for p = 1:n
        for q = 1:n
            % results for this measurement setup
            r_a = a(p) + 1; %shift by one to have values from [1,m]
%             r_b = b(q) + 1;

            S( ((p-1)*m) + r_a, ((q-1)*m) + r_b ) = 1;
        end
    end
    A(:,r) = reshape(S,n*n*m*m,1);
    r = r + 1;

    a = next_strategy(a,n,m);
end

b = zeros(n,1);
r_a = 2;

for i = 1:t-1
    % the behaviour as matrix
    S = zeros(n*m,n*m);
    
    % go over all measurement setups
    for p = 1:n
        for q = 1:n
            % results for this measurement setup
%             r_a = a(p) + 1; %shift by one to have values from [1,m]
            r_b = b(q) + 1;
            S( ((p-1)*m) + r_a, ((q-1)*m) + r_b ) = 1;

        end
    end
    A(:,r) = reshape(S,n*n*m*m,1);
    r = r + 1;

    b = next_strategy(b,n,m);
end


end

function na = next_strategy(a,n,m)
%
% Increment the strategy
%
% INPUT
% a: deterministic strategy vector
%
% OUTPUT
% na: a + 1
%
    na = a;
    for i = 1:n
        na(i) = mod(a(i)+1,m);
        if(na(i) > a(i))
            break
        end
    end
    
end