function [ A ] = local_deterministic_strategies( n,m )
%
% Output matrix containing all local deterministic strategies
%
% INPUT
% n: number of possible measurement settings on both sides
% m: number of possible outcomes per measurement
%
% OUTPUT
% A: ( (n*m)^2 x m^2n) matrix with local deterministic strategies in columns
%

% total number of local strategies (for each party)
t = m^n;

% allocate strategie vectors now
a = zeros(n,1);
b = zeros(n,1);

% counters
i = 1;
j = 1;

r = 1;

A = zeros((n*m)^2,m^(2*n));

progressbar

for i = 1:t
    for j = 1:t
        % the behaviour as matrix
        S = zeros(n*m,n*m);
        
        % go over all measurement setups
        for p = 1:n
            for q = 1:n
                % results for this measurement setup
                r_a = a(p) + 1; %shift by one to have values from [1,m]
                r_b = b(q) + 1;
                
                S( ((p-1)*m) + r_a, ((q-1)*m) + r_b ) = 1;
            end
        end
        A(:,r) = reshape(S,n*n*m*m,1);
        r = r+1;
        
        b = next_strategy(b,n,m);
    end
    progressbar(i/t);
    a = next_strategy(a,n,m);
end
progressbar(i/t);


end

function na = next_strategy(a,n,m)
%
% Increment the strategy
%
% INPUT
% a: deterministic strategy vector
%
% OUTPUT
% na: a + 1
%
    na = a;
    for i = 1:n
        na(i) = mod(a(i)+1,m);
        if(na(i) > a(i))
            break
        end
    end
    
end