function [ f, p_ns ] = is_nontrivial_bell( n,m,z,z0,B,p )
%
% Check if inequality (z,z0) is a nontrivial bell inequality by checking if
% there exists a non-signaling behaviour on the other side.
%
% INPUT
% n:
% m:
% (z,z0): hyperplane
% B: basis of normalized non-signaling space (will be computed if not
% provided)
% p: point in normalized NS space (for affine transformation) (will use
% fully mixed behaviour if not provided)
%
% OUTPUT
% f: violation of (z,z0) by p_ns
% p_ns: behaviour
%

if nargin < 6
    % this will be our origin (fully mixed)
    p = ones(n*m*n*m,1) * 1/(m*m);
end

if (nargin < 5) || isempty(B)
    B = ns_basis(n,m);
end

d = size(B,2);

% b = zeros(2*m*n*nchoosek(n,2)+n*n,1);

% b(2*m*n*nchoosek(n,2)+1:end) = 1;

lb = zeros(n*m*n*m,1);
% ub = ones(n*m*n*m,1);

z = z';

cvx_begin quiet
    variable x(d);
    maximize z*(p+B*x) - z0
    subject to
        (p+B*x) >= lb;
%         B*x <= ub;
cvx_end

f = cvx_optval;
p_ns = p+B*x;
       
end

