function [ B,C ] = ns_basis( n,m,zero_idx,normalization )
%
% Output an orthogonal basis for the non-signaling space. 
%
%
% INPUT
% n: number of possible measurements
% m: number of possible outcomes for eache measurement (e.g. m = 2)
% zero_idx: index of values to keep constant (default: [])
% normalization: include normalization constraint (default: true)
%
% OUTPUT
% B: basis for non-signaling space
% C: non-signaling, normalization and zero-constraint conditions as system
% of linear equalities
%
% Note: Per default we add normalization contraints. This makes the system
% nonhomogenous. The set of non-signaling, normalized behaviours  is {p + v
% | v \in span(B)} where p is a normalized non-signaling behvaiour. 
% This does not include the non-negativity condition!!!


if nargin < 4
    normalization = true;
end

if nargin < 3
    zero_idx = [];
end

C = ns_equalities(n,m);

if normalization
    % add normalization constraints
    for i = 1:n
        for j = 1:n
            equality = zeros(n*m,n*m);
            idx_a = (i*m-m+1):i*m;
            idx_b = (j*m-m+1):j*m;

            equality(idx_a,idx_b) = 1;

            C = [C ; equality(:)'];
        end
    end
end

% add zer0 contraints
zero_count = size(zero_idx,1);
zero_equalities = zeros(n*m*n*m,zero_count);

for i = 1:zero_count

    pos = zero_idx(i);

    zero_equalities(pos,i) = 1;
end

C = [C; zero_equalities'];


% B = C;
B = null(C);

end

