function [ C ] = ns_equalities( n,m )
%
% Output equalites that must be satisfied for non-signaling behaviour, i.e.
% Cx = 0 if non-signaling
%
% INPUT
% n: number of possible measurements
% m: number of possible outcomes for eache measurement (e.g. m = 2)
%
% OUTPUT
% C: equalities
%

C = zeros(2*m*n*nchoosek(n,2),n*n*m*m);

%counter
r = 1;

% C = [];

% all parties k = {1,2} (only consider bipartite setting)
for k = 1:2
    
    % over which measurment basis do we marginalize
    combs = nchoosek(1:n,2);
    for c = combs'
        a = c(1);
        a_prime = c(2);

        idx_a = (a*m-m+1):a*m;
        idx_a_prime = (a_prime*m-m+1):a_prime*m;
        
        % for all possible choices of basis of the other party (not k)
        for b = 1:n
            
            % over all possible outcomes for second party
            for l = 1:m
                
                % build the equality
                equality = zeros(m*n,m*n);
                
                idx_b = b*m-m+l;
                
                if (k == 1)
                    equality(idx_a,idx_b) = 1;
                    equality(idx_a_prime,idx_b) = -1;
                elseif (k == 2)
                    equality(idx_b,idx_a) = 1;
                    equality(idx_b,idx_a_prime) = -1;
                end
                
                % add it to A
%                 C = [C ; equality(:)'];
                C(r,:) = equality(:)';
                r = r + 1;
                
            end
            
        end
        
    end
end


end

