function [ A_ns ] = ns_polytope( n )
%
% Output the extremal vertices for the non-signaling polytope for n
% measurements (inputs) and 2 possible outptus.
%
% [1]	N. S. Jones and L. Masanes, ?Interconversion of Nonlocal
% Correlations,? arXiv.org, vol. quant-ph. 22-Jun.-2005.
%
% INPUT
% n: # of measurements
%
% OUTPUT
% A: extremal vertices in columns
%

perf_corr = [0.5,0;0,0.5];
anti_corr = [0,0.5;0.5,0];

local_corr = [1,0;0,0];

bb = [perf_corr,perf_corr;
      perf_corr,anti_corr];

A = [];

if (n == 2)
    %A = bb(:);
    A = reversible_local_transformations(bb(:),n);
end

if (n > 3)
    warning('Does not (yet) work for n > 3.')
end

for gx = 3:n
    
    
    for gy = 3:n
        
        b = zeros(2*n,2*n); % elementary behaviour
        b(1:4,1:4) = bb;
        
        % loop over measurements i (A) and j (B)
        for i = 1:n
            for j = 1:n

                ind_i = (i*2)-1:i*2;
                ind_j = (j*2)-1:j*2;
                
                if (i < 3) && (j < 3) 
                    % the elementary behaviour
                    continue
                end

                
                if (i < gx) && (j < gy)
                    if (i == 1) || (j == 1)
                        % borders have perfect correlation
                        b(ind_i,ind_j) = perf_corr;
                    else
                        % this is the question mark thingy
                        % TODO
                        b(ind_i,ind_j) = -1;
                    end
                    
                elseif (i >= gx) && (j < gy)
                    b(ind_i,ind_j) = [0.5,0.5;0,0];
                    
                elseif (i < gx) && (j >= gy)
                    b(ind_i,ind_j) = [0.5,0;0.5,0];
                    
                elseif (i == gx) && (j == gy)
                    b(ind_i,ind_j) = local_corr;
                    
                elseif (i >= gx) && (j >= gy)
                    b(ind_i,ind_j) = local_corr;
                end
                
                
            end
        end
        
        
        A = [A, b(:)];
%         A = [A, reversible_local_transformations(b,n)];
        
    end
end

%TODO: hanle question mark thingy
A_ns = reversible_local_transformations(A,n);
% A_ns = A;

end

function [A_rlt] = reversible_local_transformations(B,n)
% in the moment only permutation on measurements
% TODO: 2nd type of permutations

p = perms(1:n);

A1 = zeros(4*n*n,factorial(n)^2);

% "Permute the ordered set of input values for each party"
for k = 1:size(B,2)
    b = reshape(B(:,k),2*n,2*n);
    for i = 1:factorial(n) % permutations on A measurements
        for j = 1:factorial(n) % permuations on B
            idx_x = perm2idx(p(i,:));
            idx_y = perm2idx(p(j,:));
            b_perm = b(idx_x,idx_y);
            A1(:,(i-1)*factorial(n)+j) = b_perm(:);
        end
    end
end

% "Permute the ordered set of output values depening on the input"

% switch indices
a = zeros(n,1);
b = zeros(n,1);

A2 = [];

for i = 1:2^n
    for j = 1:2^n
        b = next_strategy(b,n,2);
        
        idx_a = switch2idx(a,n);
        idx_b = switch2idx(b,n);
        
        % do it for all behaviours sofar
        for k = 1:size(A1,2)
            behaviour = reshape(A1(:,k),2*n,2*n);
            behaviour_switched = behaviour(idx_a,idx_b);
            A2 = [A2, behaviour_switched(:)];
        end
        
    end
    a = next_strategy(a,n,2);
end

% A_rlt = A2;

A_rlt = unique(A2','rows')';

end

function [idx] = switch2idx(s,n)
    idx = 1:2*n;
    for i = 1:size(s);
        if (s(i) == 1)
            [ idx(2*i-1),idx(2*i) ] = swap(idx(2*i-1),idx(2*i));
        end
    end
end

function [idx] = perm2idx(p)
    idx = zeros(size(p,2)*2,1);
    for i = 1:size(p,2)
        idx(2*i-1) = 2*p(i)-1;
        idx(2*i) = 2*p(i);
    end
end

function na = next_strategy(a,n,m)
%
% Increment the strategy
%
% INPUT
% a: deterministic strategy vector
%
% OUTPUT
% na: a + 1
%
    na = a;
    for i = 1:n
        na(i) = mod(a(i)+1,m);
        if(na(i) > a(i))
            break
        end
    end
    
end


