function [ x,x0,nop ] = face_hyperplane( z,z0,A,tol, shift )
%
% find hyperplane that is face and touches points of A lying on (z,z0)
% Why? hope for a slightly more stable/better hyperplane than (z,z0)
%
% INPUT
% (z,z0): seperating hyperplane
% A: lds
% tol: tolerance (default: 1e-5)
% 
% OUTPUT
% (x,x0): face

if (nargin < 5)
    tol = 1e-5;
    shift = 0;
end

[d,s] = size(A);

map = false(s,1);
for i = 1:s
    q = A(:,i);
    diff = (z'*q - z0) - shift;
    if (abs(diff) < tol)
        map(i) = true;
    end
end

C = A(:,~map)';
Ceq = A(:,map)';

C(:,d+1) = -1;
Ceq(:,d+1) = -1;


nop = sum(map,1); % number of points touching hyperplane

b = zeros(sum(~map,1),1);
beq = zeros(nop,1);

f = zeros(d+1,1);

[x_lp,fval] = linprog(f,C,b,Ceq,beq);

x = x_lp(1:d);
x0 = x_lp(d+1);

end

