function [ a_boolean,x ] = in_polytope( p, A )
%
% Check if point p is in polytope defined by A
% 
% INPUT
% p: (n x 1) vector of behaviour
% A: (n x s) matrix with local deterministic strategies in columns
%
% OUTPUT
% inp: true if in polytop, false if outside, NaN if failed
% x: (s x 1) convex coefficients s.t. A*x = p (if exists, check exitflag)
%    NOTE: if inp == false or NaN x is undefined
%

if (size(p,1) ~=  size(A,1))
    error('Dimension mismatch.');
end

% dimension
n = size(A,1);

% number of deterministic strategies
s = size(A,2);

% use Aeq,beq parameters of linprog
Aeq = A;
Aeq(n + 1, :) = ones(1,s); % add ones to enforce convex combination

beq = p;
beq(n + 1, :) = 1;

% require lb and ub to ensure convex combination
lb = zeros(s,1);
ub = ones(s,1);

cvx_begin quiet
    variable x(s);
    subject to
        Aeq * x == beq;
        x >= lb;
        x <= ub;
cvx_end

if (abs(cvx_optval) < 2*eps)
    a_boolean = true;
elseif cvx_optval > 1
    a_boolean = false;
else
%     disp('in_polytope: sedumi failed, attempting to use matlab linprog');
    [a_boolean,x] = in_polytope_matlablinprog(p,A);
%     a_boolean = NaN;
end


end

