function [ exitflag,x ] = in_polytope_matlablinprog( p, A)
%
% Check if point p is in polytope defined by A. This version uses the
% matlab linprog routine.
% 
% INPUT
% p: (n x 1) vector of behaviour
% A: (n x s) matrix with local deterministic strategies in columns
%
% OUTPUT
% inp: true if in polytop, false if outside, NaN if failed
% x: (s x 1) convex coefficients s.t. A*x = p (if exists, check exitflag)
%    NOTE: if inp == false or NaN x is undefined
%

if (size(p,1) ~=  size(A,1))
    error('Dimension mismatch.');
end

% dimension
n = size(A,1);

% number of deterministic strategies
s = size(A,2);

% use Aeq,beq parameters of linprog
Aeq = A;
Aeq(n + 1, :) = ones(1,s); % add ones to enforce convex combination

beq = p;
beq(n + 1, :) = 1;

% require lb and ub to ensure convex combination
lb = zeros(s,1);
ub = ones(s,1);

% optimize what?
f = ones(s,1);

options = optimset('linprog');
options.Display = 'off';

[x,fval,lpexitflag] = linprog(f,[],[],Aeq,beq,lb,ub,[],options);


if (lpexitflag == 1)
    exitflag = true;
%     disp('in polytope');
elseif (lpexitflag == -2)
    exitflag = false;
%     disp('outside of polytope');
else
    exitflag = NaN;
%     disp('I dunno ... check lp output');
end

end

