function [ p,c ] = intersection_on_hull( p_in,p_out,A,k_max,tol )
%
% Find point between point p_in (in polytope) and p_out (outside of
% polytope) that is a convex combination of p_in and p_out and lies on the
% face of the polytope
%
% INPUT
% p_in: point inside
% p_out: point outside
% A: extremal points of the polytope
% k_max: maximum iterations
% tol: how close to 0
%
% OUTPUT
%
%

if nargin < 5
    tol = 1e-12;
end

if nargin < 4
    k_max = 1e4;
end

%  binary search
a = 0; b = 1; % upper and lower bounds

k = 0;

while (k < k_max) && (b - a) > tol
    

    c = (a+b)/2; 
    p = (1-c)*p_in + c*p_out;
    
%     [fval,z,z0] = seperating_hyperplane(p,A,10);
    inp = in_polytope(p,A);
%     if (isnan(inp))
%         inp = convex_combination(p,A);
%     end

            
            
    if isnan(inp) || (inp == -1)
        % optimization failed
        warning('Optimization failed!');
        break;
%     elseif (abs(fval) < tol)
        % found the point
%         break;
%         b = c;
    elseif (inp == 0)
        % too far out
        b = c;
    elseif (inp == 1)
        % too far in
        a = c;
    end
    
    k = k+1;
    
end

end

