function [ f,z,z0 ] = rowspace_hyperplane( n,m,s,A_lds,zidx,tol )
%ROWPACE_HYPERPLANE Summary of this function goes here
%   Detailed explanation goes here

if nargin < 6
    tol = 1e-10;
end

% get NS-basis (not used) and NS conditions (with zero contraints)
normalization = true;
[B,C] = ns_basis(n,m,zidx,normalization);

ridx = (sum(A_lds(zidx,:))==0);
A_null = A_lds(:,ridx); % in null space of B
A_row = A_lds(:,~ridx); % in row space of B

% choose any point that is in null space (used to find affine translation
% of hyperplane and calculate B_lds_*)
b = A_null(:,1);

% shift space to make it a vector space (not an affine space)
% B_lds_null = A_null - repmat(b,1,size(A_null,2));
B_lds_row = A_row - repmat(b,1,size(A_row,2));


% number of lds in row space
n_row = size(B_lds_row,2);

% how many possible combinations are there?
t = nchoosek(n_row,s);

% find a reduced C (C is not of full rank)
[U,S,V] = svd(C);
r = sum(diag(S) > tol); % rank of C
C_red = V(:,1:r)'; % orthonormal basis for row space of C
n_c = r;


% NS conditions minus the zero constraints
C_ns = C(1:end-size(zidx,1),:);
% Basis of ns space (normalized, for is_nontrivial_bell)
B_ns = null(C_ns);

% this usually takes the most time ...
fprintf(['Creating list of combinations...']);
if s == 1
    selections = (1:n_row)';
else
    selections = nchoosek(1:n_row,s);
end
rperm = randperm(t); % randomly permute order
disp(['done']);

disp(['Starting search, ', num2str(t),' combinations to consider.']);

progressbar(0);
i = 1;

for selection = selections(rperm,:)'
    
    progressbar(i/t);
    B_lds_max = B_lds_row(:,selection);

    cvx_begin quiet
        variable x(1,n_c);
        maximize sum(x*C_red*B_lds_max);
        subject to
            x*C_red*B_lds_row <= 0;
            x*C_red >= 0;
            x*C_red*b <= 1;
    cvx_end

    x = x';
    z = C_red'*x;
    z0 = z'*b;
%     disp_behaviour(z,n,m);
    f = is_nontrivial_bell(n,m,z,z0,B_ns,b);

    if f > tol
        break;
    end

    i = i + 1;

end

if (f > tol)
    disp(['Found non-trivial Bell. f: ',num2str(f), ' i:', num2str(i)]);
    disp_behaviour(z,n,m);
end
progressbar(1);


end

