function [ B ] = sample_in_polytope( p,A,epsilon,k )
%
% Sample k points epsilon around p in the polytope defined by A
%
% INPUT
% p: point in polytope
% A: extremal points of polytope
% epsilon: distance to sample points
% k: number of points to sample
%
% OUTPUT
% B: k points in columns
%

[d,s] = size(A);

if (size(p,1) ~= d)
    error('dimension mismatch!')
end

% find convex combination

[in_polytope,x] = convex_combination(p,A);
if (in_polytope ~= 1)
    error('p does not seem to be in polytope');
end


% calculate vector from point p to extremal points
D = zeros(d,s);
for i = 1:s
    D(:,i) = A(:,i) - p;
end

% find minimum orthogonal basis
r = rank(D);
[U,S,V] = svd(D,'econ');
U_r = U(:,1:r);

% B = U_r;

% random vectors in the epsilon sphere
% R = random_unit_vector(r,k) * epsilon;
% 
% D = U_r * R;
% 
% B = repmat(p,1,k) + D;

% rejection sampling
count = 0;
tries = 0;
B = zeros(d,k);
while (count < k)
    rev = random_unit_vector(r,1) * epsilon;
    p_sampled = p + (U_r * rev);
    [in_polytope,x] = convex_combination(p_sampled,A);
    if (in_polytope == 1)
        B(:,count+1) = p_sampled;
        count = count + 1;
    end
    tries = tries + 1;
end

rejection_rate = 1-(count/tries);

disp(['Rejection rate: ', num2str(rejection_rate*100),'%']);

end

