function KL = dist_KL_CPD (cpd1, cpd2)
%
% Compute the Kullback-Leibler distance for two CPDs
%
% Usage: KL = dist_KL_CPD (cpd1, cpd2)
%
% The basic formula is sum(p_i (log p_i - log q_i)
% This is then decomposed to -sum(p_i log q_i) - H_Shannon(p)
% Finally we define for p_i log q_i
%     0   log 0 = 0     (as per usual with Shannon's entropy)
%     p_i log 0 = +Inf  (for p_i > 0)
%
% Note: KL is zero for identical states and +Inf for ortogonal ones
%

z1 = logical(cpd1 == 0);
z2 = logical(cpd2 == 0);
if any(z2 & ~z1)
    KL = +Inf;
else
    z12 = ~(z1 | z2);
    KL = - sum(cpd1(z12).*log2(cpd2(z12)));
    KL = KL - H_Shannon(cpd1);
end

