function f = fidelity (dm1, dm2)
%
% Compute the fidelity distance between to matrices
% 
% Usage: f = fidelity(dm1, dm2)
%     dm1, dm2   The density matrices (in any order)
%     dist       0..1 for density matrices. 1 for identical matrices, 0 for orthogonal ones
%
% f = tr sqrt(dm1^0.5 dm2 dm1^0.5)
%
% Reference:
%     [1] Quantum information and quantum computation, Nielsen and Chuang (textbook), section 9.2
%

warning off MATLAB:sqrtm:SingularMatrix

d11 = sqrtm(dm1);

d33 = d11 * dm2 * d11;

d44 = sqrtm(d33);

f = real(trace(d44));

warning on MATLAB:sqrtm:SingularMatrix

