function pure = GHZ(p1, p2, p3, p4)
%
% Get an GHZ pure state
%
% Usage 1: pure = GHZ([N [, phase]])
%     N      How many particles. Default 3
%     phase  Default 0
%
% Usage 2: pure = GHZ(desc, which1, which2[, phase]);
%     Desc   Descriptor of the state
%     which1 Which value for each particle for the first part
%     which2 Which value for each particle for the second part
%     phase  Default 0
%
% pure(N,phase) is equivalent to pure(2*ones(1,N), 1+zeros(1,N), 1+ones(1,N), phase)
%

if nargin < 2
    p2 = 0;
end
if nargin < 1
    p1 = 3;
end
if nargin <= 2
    N = p1;
    phase = p2;
    pure = GHZ(2*ones(1,N), 1+zeros(1,N), 1+ones(1,N), phase);
    return;
end

if nargin <4
    p4 = 0;
end

desc = to_row(p1);
which1 = to_row(p2);
which2 = to_row(p3);
phase = p4;

tensor = zeros(desc);
tensor (sub3ind(desc,which1)) = 1/sqrt(2);
tensor (sub3ind(desc,which2)) = exp(i*phase)/sqrt(2);


pure = cleanup(tensor2pure(tensor));
