function pure = W101(p1,p2,p3,p4)
%
% Generate the (generalized) W state
%
% Usage 1: W101([N[, m]])
%     N         How many particles. Default is 3
%     m         How many up (1) bits. Default is 1
%
% Usage 2: W101(desc, whats_0, whats_1[, m])
%     desc      The state's descriptor
%     whats_0   What is the down bit for each particle
%     whats_1   What is the up bit for each particle 
%     m         How many up bits? Default is 1
% 
% Note: W101(N,m) is equivalent to W101(2*ones(1,N), 1+zeros(1,N), 1+ones(1,N),m)
%

if nargin < 3
    if nargin < 2
        p2 = 1;
    end
    if nargin < 1
        p1 = 3;
    end
    N = p1;
    m = p2;
    pure = W101(2*ones(1,N), 1+ones(1,N), 1+zeros(1,N),m);
    return;
end

if nargin < 4
    p4 = 1;
end
desc = to_row(double(p1));
whats_what = [to_row(p2); to_row(p3)];
m = p4;
N = length(desc);


tensor = zeros(desc);

all_idxs_1 = all_perm_by_count([1 2],[N-m m]);
all_idxs_2 = all_idxs_1;
for k=1:N
    all_idxs_2(:,k) = whats_what(all_idxs_1(:,k),k);
end

tensor(sub3ind(desc, all_idxs_2)) = 1/sqrt(N);

pure = tensor2pure(tensor);
