function [gate, new_desc] = control_gate(op, desc)
%
% Generate a controlled-gate operator, with the control being the first
% qbit in the resulting operator
%
% Usage:[gate<, new_desc>] = control_gate(op<, desc>)
%     op         The operator which is being controlled
%     desc       The descriptor of the state (optional if all qbits)
%     gate       The generated gate
%     new_desc   [2 desc], optional, if desc supplied or all qbits
%
% If the control bit is 1, "op" is executed. Otherwise, not.
%

n = length(op);
gate = [eye(n) zeros(n); zeros(n) op];

if nargout > 1
    if nargin > 1
        new_desc = [2 to_row(desc)];
    else
        new_desc = [2 gen_desc(op)];
    end
end