function yes_no = is_majorizationally_incompatible (the_one, the_other)
%
% Are two density matrices "incompatible" (in the mahjorization / conversion) sense?
%
% Usage: yes_no = is_majorizationally_incompatible (dm1, dm2)
%     dm1, dm2    The two density matrices
%     yes_no      The reply
%
% Two matrices are "incompatible" if neither one majorizes the other
%
% Reference: 
%     [1] Majorization and its application in quantum information theory, M. A. Nielsen
%     [2] Majorization and the interconversion of bipartite states, Nielsen and Vidal,
%         Quantum Information and Computation 1, 76–93, 2001
%

yes_no = (is_majorized_by(the_one, the_other) || is_majorized_by (the_other, the_one));