function yes_no = is_majorized_by (which, by_whom)
%
% Is the first DM majorized by the second?
%
% Usage: yes_no = is_majorized_by (which, by_whom)
%     which       The matrix majorized by "by_whom"
%     by_whom     The matrix which majorizes "which"
%     yes_no      The reply
%
% Reference: 
%     [1] Majorization and its application in quantum information theory, M. A. Nielsen
%     [2] Majorization and the interconversion of bipartite states, Nielsen and Vidal,
%         Quantum Information and Computation 1, 76–93, 2001
%


v1 = cumsum(majorization_vector(which));
v2 = cumsum(majorization_vector(by_whom));

if ~ is_close(v1(end), v2(end))
    yes_no = 0;
    return;
end

yes_no = (mminn(v1 <= v2) == 1);