function tensor = dm2tensor (dm, desc)
%
% Transforms a density matrix into a density tensor
%
% Usage: tensor = dm2tensor (dm<, desc>)
%     dm - The density matix
%     desc - The descriptor (optional if all qbits)
%     tensor - The density tensor
%
% Note: To generate an A x B x C x D density matrix, the Matlab syntax is
%       kron(A,kron(B,kron(C,D))). Also note that outer multiplication is 
%       associative. Therefore the above is equal to kron(kron(A,B),kron(C,D)), 
%       for example.
%

if nargin < 2
    desc = gen_desc(dm);
else
    desc = to_row(desc);
end

desc = fliplr(desc);

dm2 = reshape(dm, [desc,desc]); % Indexing is now (... C_ket, B_ket, A_ket, ..., C_bra, B_bra, A_bra)
                                % (ket-s are the rows, bra-s are the columns)

N = length(desc);
ordering = zeros(1,2*N);
ordering(2*([1:N]-1)+1) =   N - [1:N] + 1;
ordering(2*([1:N]-1)+2) = 2*N - [1:N] + 1;

tensor = permute(dm2, ordering);
