function [res_dm, res_desc, res_names] = ipermute_dof_dm (rev_ordering, dm, desc, names)
%
% Invert permutation of degrees of freedom (particles) in a density matrix
%
% Usage: [res_dm<, res_desc<, res_names>>] = ipermute_dof_dm (ordering, dm<, desc<, names>>)
%     ordering - The new ordering of the DoF. 
%         For permute... : 
%                  You have: A B C D
%                  You want: C B D A
%                  You give: 3 2 4 1
%         For ipermute... :
%                  You have: C B D A
%                  You want: A B C D
%                  You give: 3 2 4 1
%
%     dm - The density matrix
%     desc - The description (optional if all qbits)
%     names - Names of the DoF (optional if A B C D ...)
%     res_dm - The permuted dm
%     res_desc - The permuted descriptor (optional)
%     res_names - The permuted names (optional)
%

ordering(rev_ordering) = 1:length(rev_ordering);

if nargin < 3
    desc = gen_desc(dm);
end
N = length(desc);
desc = reshape(desc,1,N); % Make sure it's a row vector

t1 = dm2tensor(dm,desc);

full_ordering = zeros(1,2*N);
full_ordering((1:N)*2  ) = ordering*2;
full_ordering((1:N)*2-1) = ordering*2 -1;

t2 = permute(t1, full_ordering);

res_dm = tensor2dm(t2);
if nargout > 1
    res_desc = permute(desc, ordering);
    if nargout > 2
        if nargin < 4
            names = gen_name_desc(length(desc));
        end
        res_names = permute_1D_cell_array(names, ordering);
    end
end
