function [res_pure, res_desc, res_names] = ipermute_dof_pure (rev_ordering, pure, desc, names)
%
% Invert permutation of degrees of freedom (particles) in a pure state
%
% Usage: [res_pure<, res_desc<, res_names>>] = permute_dof_pure (ordering, pure<, desc<, names>>)
%     ordering - The new ordering of the DoF. 
%         For permute... : 
%                  You have: A B C D
%                  You want: C B D A
%                  You give: 3 2 4 1
%         For ipermute... :
%                  You have: C B D A
%                  You want: A B C D
%                  You give: 3 2 4 1
%
%     pure - The density matrix
%     desc - The description (optional if all qbits)
%     names - Names of the DoF (optional if A B C D ...)
%     res_pure - The permuted pure
%     res_desc - The permuted descriptor (optional)
%     res_names - The permuted names (optional)
%

ordering(rev_ordering) = 1:length(rev_ordering);

if nargin < 3
    desc = gen_desc(pure);
end
N = length(desc);
desc = reshape(desc,1,N); % Make sure it's a row vector

t1 = pure2tensor(pure,desc);
t2 = permute(t1, ordering);

res_pure = tensor2pure(t2);
if nargout > 1
    res_desc = permute(desc, ordering);
    if nargout > 2
        if nargin < 4
            names = gen_name_desc(length(desc));
        end
        res_names = permute_1D_cell_array(names, ordering);
    end
end
