function [pt,pt_desc,pt_name_desc] = partial_trace (dm, keep_mask, desc, name_desc)
%
% Partial trace
%
% Usage: pt = partial_trace (dm, keep_mask<, desc>)
%     dm - The original dm
%     keep_mask - Which "particles" to keep (an array of 0/1)
%     desc - A descriptor of the dm. Optional if all qbits
%     pt - The partially traced dm
%     pt_desc - A descriptor of the traced dm
%     

keep_mask = logical(keep_mask);

if nargin < 3
    desc = gen_desc(dm);
end
desc = to_row(desc); 
if nargin < 4
    name_desc = gen_name_desc(length(desc));
end

if nargout > 1
    pt_desc = desc(keep_mask);
    if nargout > 2
        pt_name_desc = name_desc(keep_mask);
    end
end


if min(keep_mask) == 1
    pt = dm;
    return;
end

% Create a mask to indicate which elements to keep
t1 = dm2tensor(dm,desc);

faktor = 1;
for d=1:length(desc)
    if keep_mask(d)
        faktor = kron(faktor, ones(desc(d)));
    else
        faktor = kron(faktor, eye (desc(d)));
    end
end

faktor2 = dm2tensor(faktor,desc);

t2 = t1 .* faktor2;

% Sum along dimensions we don't keep
% (from end to start to keep dim of not-yet-summed DoF constant)
for d=length(desc):-1:1
    if ~keep_mask(d)
        t2 = sum(t2, (d-1)*2+1+1);
        t2 = sum(t2, (d-1)*2+1);
    end
end

pt = tensor2dm(t2);
