function [pt_cpd, pt_desc] = partial_trace_cpd (cpd, keep_mask, desc)
%
% Partial trace a CPD
%
% Usage: [pt<,pt_desc>] = partial_trace (dm, keep_mask<, desc>)
%     cpd         The original cpd
%     keep_mask   Which "particles" to keep (an array of 0/1)
%     desc        A descriptor of the cpd. Optional if all qbits
%     pt          The partially traced cpd
%     pt_desc     A descriptor of the traced cpd (optional)
%     

keep_mask = logical(keep_mask ~= 0);

if nargin < 3
    desc = gen_desc(cpd);
end

pt_tensor = reshape(cpd,desc);

for z=length(keep_mask):-1:1
    if ~keep_mask(z)
        pt_tensor = sum(pt_tensor,z);
    end
end
pt_cpd = to_col(pt_tensor);

if nargout > 2
    pt_desc = desc(keep_mask);
end