function [pt,pt_desc] = partial_trace_pure(pure, keep_mask, desc)
%
% Partial trace
%
% Usage: pt = partial_trace_pure (pure, keep_mask<, desc>)
%     pure - The original pure state
%     keep_mask - Which "particles" to keep (an array of 0/1)
%     desc - A descriptor of the state. Optional if all qbits
%     pt - The partially traced state (now a density matrix)
%     pt_desc - A descriptor of the traced state
%     

if min(keep_mask) == 1
    pt = pure2dm(pure);
    if nargout > 1
        if nargin < 3
            desc = gen_desc(pure);
        end
        pt_desc = desc;
    end
    return;
end

[new_pure, new_desc] = reorder_and_merge_pure_dims(pure, ~logical(keep_mask), desc);
    % We now have two indices, the first being kept, the second traced over
    % The mask passed to "reorder" will have 0 for the kept DoF, 1 for
    % those not. How come? "reorder" cares only for numbering of
    % subsystems, not logical values
    
tensor = pure2tensor(new_pure, new_desc);

pt = NaNs(new_desc(1));

for y=1:new_desc(1)
    for x=1:new_desc(1)
        s = 0;
        for k = 1:new_desc(2)
            s = s + tensor(y,k)*conj(tensor(x,k));
        end
        pt(y,x) = s;
    end
end

if nargout > 1
    pt_desc = desc(keep_mask);
end