function [res_dm, res_desc, res_names] = partial_transpose (dm, flip_mask, desc, name_desc)
%
% Transpose a subset of the DoF (particles)
%
% Usage: [res_dm<, res_desc<, res_names>>] = partial_transpose (dm<, flip_mask<, desc<, name_desc>>>)
%     dm          The density matrix
%     flip_mask   Which DoF do you want to transpose?
%     desc        The description (optional if all qbits)
%     names       Names of the DoF (optional if A B C D ...)
%     res_dm      The permuted dm
%     res_desc    The permuted descriptor (optional)
%     res_names   The permuted names (optional)
%

if nargin < 3
    desc = gen_desc(dm);
end
N = length(desc); desc = to_row(desc); 
if (nargin < 2) && (N == 2)
    flip_mask = [0 1];
end

t1 = dm2tensor(dm,desc);

ordering = [1:(2*N)];
for k=1:length(flip_mask)
    if flip_mask(k)
        ordering((k-1)*2 + 1) = (k-1)*2 + 2;
        ordering((k-1)*2 + 2) = (k-1)*2 + 1;
    end
end


t2 = permute(t1, ordering);

res_dm = tensor2dm(t2);
if nargout > 1
    res_desc = desc(ordering);
    if nargout > 2
        if nargin < 4
            names = gen_name_desc(length(desc));
        end
        res_names = permute_1D_cell_array(names, ordering);
    end
end

