function [dm2, desc2] = reorder_and_merge_dm_dims (dm, mask, desc)
%
% Reorder and merge particles in a density matrix
%
% Usage: [dm2<, desc2>] = reorder_and_merge_dm_dims (dm, mask<, desc>)
%     dm     The original density matrix
%     mask   How to merge/reorder. See below for details
%     desc   The density matrix's descriptor. Optional for qbits
%     dm2    The resulting density matrix
%     desc2  The resulting descriptor. Optional
%
% The mask is a partition mask - identical values indicate the particles
% belog to the same partition. The ordering of the "new particles", a.k.a.
% partitions is by the ordering of the partition "numbers" - the values in
% the mask.
%


if nargin < 3
    desc = gen_desc(dm);
end

partitions = unique(mask);

permutation = NaNs(1,length(desc)*2);
new_desc    = NaNs(1,length(partitions)*2);

pos = 1;
for k=1:length(partitions);
    where  = to_row(find(mask == partitions(k)));
    count = length(where);
    prev_location = [(where*2-1) where*2];
    permutation(pos:(pos + count*2 - 1)) = prev_location;
    pos = pos + count*2;
    new_dims(k*2-1) = prod(desc(where));
    new_dims(k*2)   = new_dims(k*2-1);
end
new_desc = new_dims(1:2:end);


t1 = dm2tensor(dm, desc);
t2 = permute(t1, permutation); clear t1;
t3 = reshape(t2, new_dims); clear t2;
dm2 = tensor2dm(t3); clear t3;

if nargin > 1
    desc2 = new_desc;
end