function [pure2, desc2] = reorder_and_merge_pure_dims (pure, mask, desc)
%
% Reorder and merge particles in a pure state
%
% Usage: [pure2<, desc2>] = reorder_and_merge_pure_dims (pure, mask<, desc>)
%     pure   The original pure state
%     mask   How to merge/reorder. See below for details
%     desc   The pure state's descriptor. Optional for qbits
%     pure2  The resulting pure state
%     desc2  The resulting descriptor. Optional
%
% The mask is a partition mask - identical values indicate the particles
% belog to the same partition. The ordering of the "new particles", a.k.a.
% partitions is by the ordering of the partition "numbers" - the values in
% the mask.
%

if nargin < 3
    desc = gen_desc(pure);
end

partitions = unique(mask);

permutation = NaNs(1,length(desc));
N = length(unique(partitions));
new_dims    = NaNs(1,N);

pos = 1;
for k=1:N
    where  = to_row(find(mask == partitions(k)));
    count = length(where);
    permutation(pos:(pos + count - 1)) = where;
    pos = pos + count;
    new_dims(k) = prod(desc(where));
end

new_dims_tag = new_dims;
if length(new_dims_tag) == 1
    new_dims_tag = [new_dims_tag 1];
end
t1 = pure2tensor(pure, desc);
t2 = permute(t1, permutation); clear t1;
t3 = reshape(t2, new_dims_tag); clear t2;
pure2 = tensor2pure(t3); clear t3;

if nargin > 1
    desc2 = new_dims;
end