function c = concurrence (dm)
%
% Concurrence for a 2-qubit DM
%
% Usage: c = concurrence (dm)
%     dm   The 4x4 matrix
%     c    The concurrence
%
% Reference:
% [1] "Entanglement of Formation of an Arbitrary State of Two Qubits", William K. Wootters,  Phys. Rev. Lett. 80, 2245�2248 (1998)
%

sigma22 = [0 0 0 -1; 0 0 1 0; 0 1 0 0; -1 0 0 0];

rho_tilde = sigma22 * conj(dm) * sigma22;

e = sort(eig(dm*rho_tilde)).^(1/2);
c = max(real(e(4)-e(3)-e(2)-e(1)),0);