function yes_no_nan = is_entangled_all_pt(state, desc)
%
% Try to ascertain if a given state is entangled using the Peres-Horodecki criteria.
% For multi-particle states will try all bipartite divisions
%
% For more than 2 particles, the function will attempt all partial transpositions, 
% unless a specific mask is specified.
%
% Usage: yes_no_nan = is_entangled_all_ppt(state<, desc)
%     
%     state       The density matrix
%     desc        The state's descriptor
%     yes_no_nan  If the state has a descriptor [2 2], [2 3] or [3 2] the
%                 answer will be either yes (1) or no (0). Otherwise, the answer will be 
%                 either yes (1) or "i don't know" (NaN)
%
% Reference:
%     [1] Separability of Mixed States: Necessary and Sufficient Conditions, Horodecki M, Horodecki P, Horodecki R, quant-ph/9605038
%     [2] Separability criterion for density matrices, A. Peres, quant-ph/9604005
%

if nargin < 2
    desc = gen_desc(state);
end

if size(state,2) == 1
    state = pure2dm(state);
end

masks = all_bipartition_masks(length(desc));
yes_no_nan = NaN;

for k=1:(size(masks,1)-1) % -1: Don't do the all-in mask - there's no point
    yes_no_nan = yn3_or(yes_no_nan, is_entangled_pt(state, masks(k,:), desc));
end
