function lng = logarithmic_negativity(dm, mask, desc)
%
% Compute the logarithmic negativity for a given bipartite division of a dm
%
% Usage: ng = logarithmic_negativity(dm, mask, desc)
%     dm     The density matrix
%     mask   The bipartition mask
%     desc   DM descriptor
%     lng    The resulting logarithmic negativity
%
% References:
%     [1] A computable measure of entanglement, Vidal & Werner, quant-ph/0102117
%

if nargin < 3
    desc = gen_desc(dm);
end
if (nargin < 2) && (length(desc) == 2)
    mask = [0 1];
end

lng = log2(trace_norm(partial_transpose(dm,mask,desc)));

