function ng = negativity(dm, mask, desc)
%
% Compure the negativity for a given bipartite division of a dm
%
% Usage: ng = negativity(dm, mask, desc)
%     dm     The density matrix
%     mask   The bipartition mask (optional for two particles)
%     desc   DM descriptor (optional for all qubits)
%     ng     The resulting negativity
%
% References:
%     [1] A computable measure of entanglement, Vidal & Werner, quant-ph/0102117
%

if nargin < 3
    desc = gen_desc(dm);
end
if (nargin < 2) && (length(desc) == 2)
    mask = [0 1];
end

ng = cleanup(trace_norm(partial_transpose(dm,mask,desc)) - 1);


