function le = linear_entropy (rho, rescale_012)
%
% Compute the linear entropy of a given density matrix
%
% Usage: le = linear_entropy (rho)
%     rho          The dm
%     rescale_012  "How much" rescaling do you wish? See below
%     le           The resulting linear entropy
%
% Rescaling: 
%     The "textbook definition" of linear entropy is simply 1 - trace^2
%     This is not naturally scaled, as it is N-1/N for the maximally mixed
%     state. We therefore provide the following options for scaling:
%     0   The unscaled version
%     1   Scaled so that the totally mixed state has linear entropy 1
%     2   Scaled so that the totally mixed state has the value of the Von-Neumann entropy for that state
%
% Reference:
% [1] "Linear entropy and Bell inequalities", Santos and Ferrero, Phys. Rev. A 62, 024101

le = 1 - trace(rho*rho);

if nargin > 1
    if rescale_012 == 1
        le = le * length(rho)/(length(rho)-1);
    elseif rescale_012 == 2
        le = le * length(rho)/(length(rho)-1) * log2(length(rho));
    end
end

le = real(le); % Get rid of tiny imaginary part (numerics)