function [DMs, probability] = collapse_povm (dm, Krauss_set)
%
% Compute the various collapsed "universes" and their probabilities when
% applying a projective measurement on a system
%
% Usage: [DMs<, probability] = collapse (dm, Krauss_set)
%     dm            The universe
%     Krauss_set    A cell array of Krauss operators            
%     DMs           A cell array (DMs{1}, DMs{2}, ...) of the various
%                   resulting "universes", with the DoF in "on_which" traced out.
%     probability   A vector of probabilities for each "universe"
%
% Notes: 
%     1. length(DMs) == length(probability) == length(Krauss_set)
%     2. Use "vrand(probability)" to choose into which world you collapse
%

N = length(Krauss_set);

DMs = {};
probability = NaNs(1,N);

for k=1:N
    Z = Krauss_set{k} * dm * Krauss_set{k}';
    probability(k) = real(trace(Z));
    DMs{k} = Z / trace(Z);
    validate_dm(DMs{k})
end