function Krauss_set_complete = complete_Krauss_set (Krauss_set_partial)
%
% Complete a Krauss set to sum unity (if needed)
%
% Usage: Krauss_set_complete = complete_Krauss_set (Krauss_set_partial))
%
% Notes: 
% 1. If no completion is needed, none is done
% 2. Although there is no strict validation of the set, (see validate_Krauss_set for that),
%    we make sure the completing member is valid. If not, an error is
%    issued.
%

S = zeros(size(Krauss_set_partial{1}));
for k=1:length(Krauss_set_partial)
    K = Krauss_set_partial{k};
    F = K'*K;
    S = S + F;
end

Krauss_set_complete = Krauss_set_partial;

if ~is_close(S,eye(length(S)))
    ZZ = eye(length(S)) - S;
    if ~is_pos_semidef(ZZ)
        error ('Cannot complete the Krauss set. Missing piece is not positive semi-definite');
    end
    [v,d]=eig(ZZ);
    Z = v*d.^(1/2)*v';
    Krauss_set_complete{end+1} = Z;    
end