function yn = is_Krauss_set_valid (Krauss_set)
%
% Is a set of Krauss operators valid?
%
% Usage: yn = is_Krauss_set_valid (Krauss_set)
%
% Conditions tested:
%     Krauss_set{i}'*Krauss_set{i} >= 0 for all i
%     sum(Krauss_set{i}'*Krauss_set{i}) == 1
%

S = zero(size(Krauss_set{1}));
for k=1:length(Krauss_set)
    F = K'*K;
    if ~is_pos_semidef(F)
        yn = false;
        return;
    end
    S = S + F;
end

if ~is_close(S, eye(length(S)))
    yn = false;
    return;
end

yn = true;

