function Krauss_set_out = validate_Krauss_set(Krauss_set_in)
%
% Validate a set of Krauss operators (return set as-is or issue an error)
%
% Usage: Krauss_set_out = validate_Krauss_set(Krauss_set_in)
%     Krauss_set_in   A cell array of matrices
%     Krauss_set_out  The same set
%
% Conditions tested:
%     Krauss_set{i}'*Krauss_set{i} >= 0 (pos. semi-def.) for all i
%     sum(Krauss_set{i}'*Krauss_set{i}) == 1
%

S = zeros(size(Krauss_set_in{1}));
for k=1:length(Krauss_set_in)
    K = Krauss_set_in{k};
    F = K'*K;
    if ~is_pos_semidef(F)
        fprintf ('Krauss operator no. %d (K''*K) is not positive\n', k);
        disp(Krauss_set_in{k});
        disp(eig(Krauss_set_in{k}));
        error ('Krauss set invalid');
    end
    S = S + F;
end

if ~is_close(S, eye(length(S)))
    disp ('Krauss set sum is:');
    disp (S);
    error ('Krauss set does not sum up to 1');
end

Krauss_set_out = Krauss_set_in;
