function SU_gen_cache(Ns)
%
% Cahces various calculations having to do with the SU group and it's parametrizations.
% 
% Usage: SU_gen_cache(Nmax)
%     Ns - For which Ns to create the SU generators?
%
% Results are stored in the following global variables, all starting with "QLib.SU.gen"
%     QLib.SU.gen{n} - A structure containing N^2-1 matrices of NxN each: QLib.SU.gen{n}{k}(i,j)
%     QLib.SU.gen_eigval{n}{k} - nxn matrix, whose columns are the generator's eigenvalues
%     QLib.SU.gen_eigvec{n}{k} - The eigenvectors associated with the above
%     QLib.SU.gen_inv_eigvec{n}{k} - The eigenvectors of the inverse matrix
%

if nargin == 0
    Ns = [1:10];
end

global QLib;

if ~isfield(QLib, 'SU') 
    QLib.SU.gen = {}; 
    QLib.SU.gen_eigval = {}; 
    QLib.SU.gen_eigvec = {}; 
    QLib.SU.gen_inv_eigvec = {};
    QLib.SU.gen_norm = {};
end

for N=Ns
    if (length(QLib.SU.gen) < N) || (numel(QLib.SU.gen{N}) == 0)
        QLib.SU.gen{N} = SU_gen_calc(N);
        QLib.SU.gen_eigval{N} = {}; 
        QLib.SU.gen_eigvec{N} = {}; 
        QLib.SU.gen_inv_eigvec{N} = {};
        QLib.SU.gen_norm{N} = {};

        for k=1:N^2
            [QLib.SU.gen_eigvec{N}{k}, tmp] = eig(QLib.SU.gen{N}{k});
            QLib.SU.gen_eigval{N}{k} = diag(tmp);
            QLib.SU.gen_inv_eigvec{N}{k} = (QLib.SU.gen_eigvec{N}{k})^-1;
            QLib.SU.gen_norm{N}{k} = trace(QLib.SU.gen{N}{k}*QLib.SU.gen{N}{k}');
        end
    end
    QLib.SU.param_form{N} = SU_param_form(N);
end

