function ret = param_SU_1(p)
% 
% Parametrization of SU(N)
%
% Usage: ret = param_SU_1(p)
%     p - Vector of N^2-1 elements
%     ret - The SU(N) member
%
% For details of this parametrization, see the reference below.
%
% Notes:
%     * The routine determines the N in SU(N) from the length of p
%     * Although all parameters are cyclic, they have different periods, due to the different eigenvalues 
%       of the generators of the algebra. Order of magnitude is 1/sqrt(N)
%
% References: 
%     math-ph/0205016: Generalized Euler Angle Parametrization for SU(N), Tilma & Sudarshan
%

global QLib;

N = sqrt(length(p) + 1);
ret = eye(N);

if N > length(QLib.SU.param_form)
    SU_gen_cache(N);
end

for k=1:length(p)
    kk = QLib.SU.param_form{N}(k);
    ret = ret * (QLib.SU.gen_eigvec{N}{kk}*diag(exp(i*QLib.SU.gen_eigval{N}{kk}*p(k)))*QLib.SU.gen_inv_eigvec{N}{kk});
%   ret = ret * expm(i*QLib.SU.gen{N}{kk}*p(k));  
%       The two calculations are equivalent, with the upper one being faster. 
%       Acceleration is achieved by caching of eigenvals/vecs
end
