function ret = param_SU_2(p)
% 
% Parametrization of SU(N) - a trivial alternative
%
% Usage: ret = param_SU_2(p)
%     p - Vector of N^2-1 elements
%     ret - The SU(N) member
%
% The N^2-1 parameters are simply the factors multiplying the N^2-1
% generators
%
% Notes:
%     * The routine determines the N in SU(N) from the length of p
%     * Although all parameters are cyclic, they have different periods, due to the different eigenvalues 
%       of the generators of the algebra. Order of magnitude is 1/sqrt(N)
%


global QLib;

N = sqrt(length(p) + 1);

exponent = zeros(N,N);

for k=1:length(p)
    exponent = exponent + p(k) * QLib.SU.gen{N}{k};
end

ret = expm(i*exponent);
