function ret = param_U_1(p, param_SU_func)
% 
% Parametrization of U(N)
%
% Usage: ret = param_U_1(p)
%     p - Vector of N^2 elements
%     param_SU_func - The parametrization used for SU. Default is @param_SU_1
%     ret - The U(N) member
%
% For details of this parametrization, see the reference below. 
% The difference with SU(N) is simply a global phase, linked to p(N^2)
%
% Notes:
%     * The routine determines the N in SU(N) from the length of p
%     * Although all parameters are cyclic, they have different periods, due to the different eigenvalues 
%       of the generators of the algebra. Order of magnitude is 1/sqrt(N)
%
% References: 
%     math-ph/0205016: Generalized Euler Angle Parametrization for SU(N), Tilma & Sudarshan
%

if nargin < 2
    param_SU_func = @param_SU_1;
end

N = sqrt(length(p));
ret = param_SU_func(p(1:end-1)) .* exp(i*p(end));
