function ret = prod_SU_gens (desc)
%
% Internal use: Get the generators for an U(prod(desc)) built from generators of 
% U(desc(k)) as U_ijk... = kron(U(desc(1))_i, kron (U(desc(2))_j, ...
%
% Usage: ret = prod_SU_gens (desc)
%     desc    The descriptor
%     ret     A "struc", with the following fields
%         desc       The original descriptor
%         which_gen  A prod(desc) by length(desc) cell array which
%                        specify for each row 
%
% See mat2sun, sun2mat for further details
%

global QLib;

key = prod_SU_gens_desc_struct_key(desc);

if isfield(QLib, 'prod_gen')
    if isfield(QLib.prod_gen, key)
        ret = QLib.prod_gen.(key);
        return;
    end
else
    QLib.prod_gen = struct;
end

ret.desc = desc;

N = prod(desc);

ret.which_gen = gen_all_idxs(desc.^2);

ret.gen = cell(N^2,1);
ret.gen_norm = NaNs(N^2,1);

for k=1:size(ret.which_gen,1)
    o = 1;
    for n=1:length(desc)
        o = kron(o, QLib.SU.gen{desc(n)}{ret.which_gen(k,n)});
    end
    ret.gen{k} = o;
    ret.gen_norm(k) = trace(o*o');
end

QLib.prod_gen.(key) = ret;