function S = RatMat(A, row_sep, accuracy)
%
% RatMat: Convert a matrix to symbolic form (fix for Matlab's sym).
% 
% Usage: S = RatMat(A, row_sep, accuracy)    
%     A         The matrix to convert. May be complex.
%     row_sep   The row separator. Defaults to ';', which is appropriate for Maple
%     accuracy  accuracy requirement in converting floating-point to rational (using "rats")
%
% Used primarily as part of JordanFix
%

    function s = do_rats(a)
        s='';
        have_real = abs(real(a)) > 0;
        have_imag = abs(imag(a)) > 0;
        if have_real
            s = [s strtrim(rats(real(a),accuracy))];
        end
        if have_real && have_imag
            s = [s '+'];
        end
        if have_imag
            s = [s 'i*' strtrim(rats(imag(a),accuracy))];
        end
        if ~(have_imag || have_real)
            s = '0';
        end
    end

if nargin < 3
    accuracy = 25;
end

A = cleanup(A);   % Note: This is probably preferable, but one may argue otherwise

row_prefix = '[';
row_suffix = ']';
if nargin < 2
    row_sep = ';';
end

S = '[';
for row=1:size(A,1)
    S = [S row_prefix];
    for col=1:size(A,2)
        S = [S do_rats(A(row,col))];
        if col < size(A,2)
            S = [S ', '];
        end
    end
    S = [S row_suffix];
    if row < size(A,1)
        S = [S row_sep];
    end
end
S = [S ']'];

end

