function D = doubleFixMatlabRootOfBug(symD,sizeHint)
%
% doubleFixMatlabRootOfBug: fix a matlab bug in the "double" function converting a symbolic matrix from Maple. 
%
% This is used as part of JordanFix.
%


if isequal(size(symD),[1,1])
    s0 = char(symD);
    if s0(1) == '['
        % We have a matrix here - slightly different handling
        s = ['[' s0 ']'];
        s = strrep(s,'[1]','');
        matrix_as_char = maple(['evalf(' s ')']);
        rows_range_str = maple(['ArrayDims(Array(' matrix_as_char '))[1]']);
        cols_range_str = maple(['ArrayDims(Array(' matrix_as_char '))[2]']);
        rows = str2num(rows_range_str((strfind(rows_range_str, ' .. ')+4):end));
        cols = str2num(cols_range_str((strfind(cols_range_str, ' .. ')+4):end));
        D = reshape (str2num(matrix_as_char), [rows, cols]);
        return;
    end
    % It's a scalar - will be handled ok in the next section
end

% Not a matrix - handle one element 
D = NaNs(size(symD));
for k=1:numel(symD)
    try
        s0 = char(symD(k));
        s = strrep(s0,'[1]','');
        s2 = ['evalf(' s ')'];
        D(k) = str2num(maple(s2));
    catch
        D = NaNs(size(symD));
        return;
    end
end 
