function s = format_delta_t(secs)
%
% Format a period of time suppied in seconds as an easy-to-read string
%
% Usage: s = format_delta_t(secs)
%
% Examples:
%     format_delta_t(3.21)         '3.2s'
%     format_delta_t(43.21)        '43.2s'
%     format_delta_t(543.21)       '9:03s'
%     format_delta_t(6543.21)      '1:49m'
%     format_delta_t(76543.21)     '21:16m'
%     format_delta_t(876543.21)    '10d 3h'
%     format_delta_t(9876543.21)   '114d 7h'
%

if secs < 60
    s = sprintf ('%.1fs', secs);
elseif secs < 60*60
    s = sprintf ('%d:%02ds', floor(secs/60), round(mod(secs,60)));
elseif secs < 60*60*24
    s = sprintf ('%d:%02dm', floor(secs/3600), round(mod(secs,3600)/60));
else
    s = sprintf ('%dd %dh', floor(secs/86400), round(mod(secs,86400)/3600));
end