function idxs = gen_all_idxs (varargin)
%
% For a multi-dimentional array, generate a list of all possible indexes into the array
% 
% Usage: idxs = gen_all_idxs (varargin)
%     varargin  Dimensions of the array
%     idxs      A cell array of prod(dims) rows and length(dims) columns
%
% Usage example:
%     arr = rand(2,3,5);
%     idxs = gen_all_idxs(size(arr));
%     for k=1:size(idxs,1)
%         arr(idxs{k,:})
%     end
%

dims = [];
for k = 1:nargin
    dims = cat(2, dims,to_row(varargin{k}));
end
n = length(dims);
N = prod(dims);

zz = NaNs(N,n);
for col = 1:n
    z = 1;
    for k = 1:n
        if col == k
            z = kron(z,[1:dims(k)]');
        else
            z = kron(z,ones(dims(k),1));
        end
    end
    zz(:,col) = z;
end

idxs = zz; %mat2cell(zz, ones(1,N), ones(1,n));