function mask = num2mask(num, Nbits)
%
% Convert a number to a mask (a logical array)
%
% Usage: mask = num_to_mask(num, Nbits)
%     num   - The number representing the mask
%     Nbits - How many bits to look at / size of the mask
%     mask  - A logical row vector. LSB at index 1, MSB at index Nbits 
%             MSB - Most signifcant bit, LSB - Lease significant bit
% 
% Note: Limited to a 64-bit mask (which would require "num" to be a uint64)
%

num  = uint64(num);
mask = logical(zeros(1,Nbits));

for bit=0:Nbits-1
    mask (bit+1) = logical (bitand(num,1));
    num = bitshift(num,-1);
end
