function print_matrix_for_mathematica(mat, name, use_rats, element_prefix, element_suffix)
% 
% Convert a Matlab matrix to a format you can copy & paste into Mathematica
%
% Usage: print_matrix_for_mathematica(mat, name<, use_rats<, element_prefix, element_suffix>>)
%     mat       The matrix
%     name      How do you want ot call it?
%     use_rats  Tries to convert floating-point numbers to rational fractions. Defaults to YES
%     element_prefix   Defaults to nothing
%     element_suffix   Defaults to nothing
%

if nargin < 3
    use_rats = true;
end
if nargin < 2
    name = '';
end
if nargin < 4
    element_prefix = '';
    element_suffix = '';
end

fprintf ('  RowBox[{\n');
fprintf(' TagBox[\n');
if length(name) > 0
    fprintf ('      RowBox[{"%s", "=", \n',name);
end
fprintf('    RowBox[{"(", "\\[NoBreak]",\n');
fprintf('    GridBox[{\n');

for y=1:size(mat,1);
    fprintf ('    {');
    for x=1:size(mat,2)

        fprintf ('\\(%s',element_prefix);
        if is_close(mat(y,x), 0)
            fprintf ('0');
        elseif ~is_close(real(mat(y,x)),0) && is_close(imag(mat(y,x)),0)
            % Just a real part
            if use_rats
                fprintf ('%s', rats(real(mat(y,x))));
            else
                fprintf ('%g', real(mat(y,x)));
            end
        elseif is_close(real(mat(y,x)),0) && ~is_close(imag(mat(y,x)),0)
            % Just an imaginary part
            if use_rats
                fprintf ('%s  \\[ImaginaryI]', rats(imag(mat(y,x))));
            else
                fprintf ('%g  \\[ImaginaryI]', imag(mat(y,x)));
            end
        else
            % Full complex
            if imag(mat(y,x)) > 0
                if use_rats
                    fprintf ('%s + %s  \\[ImaginaryI]', rats(real(mat(y,x))), rats(imag(mat(y,x))));
                else
                    fprintf ('%g + %g  \\[ImaginaryI]', real(mat(y,x)), rats(imag(mat(y,x))));
                end
            else
                if use_rats
                    fprintf ('%s - %s  \\[ImaginaryI]', rats(real(mat(y,x))), rats(-imag(mat(y,x))));
                else
                    fprintf ('%g - %g  \\[ImaginaryI]', real(mat(y,x)), rats(-imag(mat(y,x))));
                end
            end            
        end
        fprintf ('%s\\)', element_suffix);
        if x < size(mat,2)
            fprintf (', ');
        end
    end
    fprintf ('}');
    if y < size(mat,1)
        fprintf(',');
    end
    fprintf('\n');
end

fprintf('              },\n');
fprintf('            RowSpacings->1,\n');
fprintf('            ColumnSpacings->1,\n');
fprintf('            ColumnAlignments->{Left}], "\\[NoBreak]", ")"}]');
if length(name) > 0
    fprintf('}]');
end
fprintf(',\n');
fprintf('      Function[ BoxForm`e$, \n');
fprintf('        MatrixForm[ BoxForm`e$]]]\n');
fprintf (', ";"}]\n');
