function ndx = sub3ind(siz,idxs, do_check)
%
% Linear index from multiple subscripts in an array
% This is a variant of sub2ind, allowing you to specify the indexes as a
% row vector, rather than multiple parameters.
%
% Usage: ndx = sub2ind(siz, idxs, do_check)
%     siz  - The size of the matrix accessed
%     idxs - A matrix of indexes, one row per element of array accessed
%     do_check - Whether to verify the idxs are in range (default: no)
%     ndx  - Column vector (same num rows as idxs), with linear index
%
% See sub2ind for futher details
%

if nargin < 3
    do_check = 0;
end

siz = to_row(double(siz));
n = size(idxs,1);
d = size(idxs,2);

ofst = [1 cumprod(siz(1:(d-1)))];

idxs = idxs - 1; % We want all offsets to start at zero

ndx=zeros(n,1);
for k=1:n
    ndx(k) = sum(idxs(k,:) .* ofst);
end
ndx = ndx + 1; % Set basic offset back to 1

if do_check && ((min(ndx) < 1) || (max(ndx) > prod(siz)))
    error ('idxs provided are out of bounds');
end

