function [values, count] = unique2 (a)
%
% For a given matrix, find the unique values and the number of times they appear
%
% Usage [values, count] = unique2 (a)
%     a      The data (any dimentionality)
%     values The unique values (sorted, high to low)
%     count  How many times each value appears
%
% Note: NaNs are treated like any other number and will appear last in the "values" list.
%

if numel(a) == 0
    values = [];
    count = [];
    return;
end

a = sort(to_row(a));

last_val = NaN;
pos = 0;

for k=1:length(a)
    if isnan(a(k))
        % NaNs are at the very end
        pos = pos + 1;
        values(pos) = NaN;
        count(pos) = length(a) - k + 1;
        break;
    elseif a(k) ~= last_val
        pos = pos + 1;
        values(pos) = a(k);
        last_val = a(k);
        count(pos) = 1;
    else
        count(pos) = count(pos)+1;
    end
end
