function draw2d_func(Xs, the_func, varargin)
%
% Plot a 1d function in 2d
%
% Usage: draw2d_func(Xs, the_func, ...)
%     Xs,       Vector of the X values
%     the_func  The function to be evaluated at each point. Takes two parameters: X and Y 
%     ...       Additional parameters to pass on to the plotting function
%
% Examples:
%     Plotting my_func(x) on the [-7..4] area, wide black line
%         draw2d_func ([-7:0.03:4],@my_func, 'b-','LineWidth',2);
%     Plotting x^2-3x+5 on the [-10..10] interval, dotted red line:
%         draw2d_func ([-10:0.1:10], @(x) x^2-3*x+5, 'r:');
%

Ys = Xs;

for n=1:numel(Xs)
    Ys(n) = the_func(Xs(n));
end

plot(Xs,Ys,varargin{:});
