function [out_xx,out_yy,out_zz] = draw3d_func(Xs, Ys, the_func, plot_func, varargin)
%
% Plot a 1d function in 2d
%
% Usage: draw3d_func(Xs, Ys, the_func, ...)
%     Xs,       Vector of the X values
%     the_func  The function to be evaluated at each point. Takes two parameters: X and Y 
%     ...       Additional parameters to pass on to the plotting function
%     xx,yy,zz  Optional output - the calculated points
%
% Examples:
%     Plotting my_func(x,y) on the [-7..4],[0..1] area, using surf:
%         draw3d_func ([-7:0.03:4],[0:0.01:1],@my_func, @surf);
%     Plotting x^2-2xy+3x-4y+5 on the [-10..10,-10..10] square, using surfc:
%         draw3d_func ([-10:0.1:10],[-10:0.1:10], @(x,y) x^2-2*x*y+3*x-4*y+5, @pcolor);
%

if nargin < 4
    plot_func = @surf;
end

[xx,yy] = meshgrid(Xs,Ys);
zz = NaNs(size(xx));

for n=1:numel(xx)
    zz(n) = the_func(xx(n),yy(n));
end

plot_func(xx,yy,zz,varargin{:});

if nargout == 3
    out_xx = xx;
    out_yy = yy;
    out_zz = zz;
end