function draw_hist(values, the_func, varargin)
%
% Draw a historgram of values returned from a given function
%
% Usage: draw_hist(values, the_func, ...)
%     values      Values for which to evaluate
%     the_func    The function to evaluate
%     ....        Additional options passed to hist
%
% Examples:
% 1.  Draw the histogram of the sine function
%     draw_hist([0:0.01:1e3], @(a) sin(a))
% 2.  Draw the histogram for the sum of 100 random numbers in the range 0..1
%     draw_hist([1:1e6], @(p) sum(randrow(100)))
%

vals = NaNs(size(values));
for k=1:length(values)
    vals(k) = the_func(values(k));
end

hist(vals,clip(ceil(numel(values)/5),10,200),varargin{:});

    