function yes_no = are_these_linearly_independent(varargin)
%
% Tests if the input parameters (vectors, matrices, tensors, etc) are linearly independent.
%
% Usage: yes_no = are_these_linearly_independent(...)
%     ...    Any number of parameters of identical dimentionality
%     yes_no 1 - Independent, 0 - Dependent
%
% Notes:
%
% 1.  You may also have all your objects in a cell-array and use {:}, for example: 
%          are_these_linearly_independent(QLib.SU.gen{5}{:})
%     which will verify that the SU(5) generators are linearly independent
%
% 2.  If you want the projection of an object X onto one of these objects, G, simply issue   
%          proj_i = trace(X*G_i)/trace(G_i*G_i)
%
% 3.  If the set you're using is linearly independent and complete (in the
%     sense it spans the whole space / number of elements is the space's DoF),
%     you may reconstruct any object by adding up proj_i * G_i (as in 2, above)
%

global QLib;

if nargin == 0
    yes_no = NaN;
    return
end

if (nargin == 1) && iscell(varargin{1})
    varargin = varargin{:};
end

sz = numel(varargin{1});
A = NaNs(sz, length(varargin));

for k=1:length(varargin)
    col = to_col(varargin{k});
    A(:,k) = col;
end

d = eig(A);
yes_no = (ssumm(abs(d) < QLib.close_enough)  == 0);
