function ret = bilinear_interp(y,x, ys, xs, data_y_x)
%
% Given a grid of values for a 2D function, compute additional points using bilinear interpolation
%
% Usage: ret = bilinear_interp(y,x, ys, xs, data_y_x)
%     y,x        The positions at which to sample (two vectors)
%     ys,xs      The ys and xs of the known function values
%     data_y_x   The value of the functions at the (ys,xs)
%     ret        A vector, same length as y and x, containing the interpolated values
%
% See Wikipedia (http://en.wikipedia.org/wiki/Bilinear_interpolation) for details
%

x_i = find(xs(2:end)>=x,1,'first')+1;
y_i = find(ys(2:end)>=y,1,'first')+1;
dx = (x - xs(x_i-1))/(xs(x_i)-xs(x_i-1));
dy = (y - ys(y_i-1))/(ys(y_i)-ys(y_i-1));
ret = [1-dx dx]*[data_y_x(y_i-1,x_i-1) data_y_x(y_i,x_i-1); data_y_x(y_i-1,x_i) data_y_x(y_i,x_i)]*[1-dy; dy]; 


