function e_tensor = epsilon_tensor(n)
%
% Compute the epsilon anti-symmetric tensor to any given degree
%
% Usage: e_tensor = epsilon(n)
%     n         The degree of the tensor
%     e_tensor  An n-dimensional tensor
%
% Note: Epsilon tensors of low degrees are cached in QLib.eps{n}
%
% Reference:
% [1] Wikipedia: http://en.wikipedia.org/wiki/Permutation
%

    function [s,sgn2] = permt(n,k)
        s = [1:n];
        fct = 1;
        sgn = +1;
        for j=2:n
            fct = fct * (j-1);
            jj = j- mod(floor(k/fct), j);
            tmp = s(j); s(j) = s(jj); s(jj) = tmp;
            if j ~= jj % "self-swap" occurs
                sgn = -sgn;
            end
        end
        if nargout > 1
            sgn2 = sgn;
        end
    end

sz = n*ones(1,n);
e_tensor = zeros(sz);

for k=1:factorial(n)
    [idx,sgn] = permt(n,k);
    e_tensor(sub3ind(sz,idx)) = sgn;
end

end

