function otrho_set = gram_schmidt(varargin)
%
% gram_schmidt: Transform a set of objects (vectors, matrices, tensors) into an orthonormal set using the Gram Schmidt process.
%
% Usage: otrho_set = gram_schmidt(varargin)
%     varargin   The set of objects (of any dimensionality).
%                The set may be specified as a list of parameters, cell array, or if the objects are column
%                vectors, as a single matrix.
%     ortho_set  The output
%
% Notes:
% 1.  The inner product is defined as sum_over_all_matching_elements(conjugate(a(i,j,k,...)),b(i,j,k,...))
% 2.  The results of the proccess is dependent on the order of parameters.
% 3.  This function can be used for many purposes, such as a preperatory step for find_span.
%

if nargin == 0
    return;
end

if (nargin==1) && iscell(varargin{1})
    varargin = varargin{1};
end

v = varargin{1};
for k=2:nargin
    v(:,(end+1):(end+size(varargin{k},2))) = varargin{k};
end

for k1=1:size(v,2)
    for k2=1:(k1-1)
        v(:,k1) = v(:,k1) - v(:,k2)*(v(:,k2)'*v(:,k1));
    end    
    ze_norm = sqrt(v(:,k1)'*v(:,k1));
    if ~is_close(ze_norm, 0)
        v(:,k1) = v(:,k1) / ze_norm;
    else
        v(:,k1) = NaN;
    end
end

otrho_set = v;