function v2 = gram_schmidt2(varargin)
%
% A gram_schmidt process, but in this version the calculation done by a diagonalization technique. 
% This results in "nicer" vectors, with more zeros
%
% Usage: otrho_set = gram_schmidt2(varargin)
%     varargin   The set of objects (of any dimensionality).
%                The set may be specified as a list of parameters, cell array, or if the objects are column
%                vectors, as a single matrix.
%     ortho_set  The output orthonormal set
%
% Notes:
% 1.  The inner product is defined as sum_over_all_matching_elements(conjugate(a(i,j,k,...)),b(i,j,k,...))
% 2.  The results of the proccess is dependent on the order of parameters.
% 3.  This function can be used for many purposes, such as a preperatory step for find_span.
%

if nargin == 0
    return;
end

if nargin == 0
    return;
end

vin = varargin{1};
for k=2:nargin
    vin(:,(end+1):(end+size(varargin{k},2))) = varargin{k};
end

z = 1;
for k=1:size(vin,1)
    vin = cleanup(vin);
    which_cols = find(vin(k,z:end),1); 
    if length(which_cols) > 0
        % make sure the k column is from the list
        if which_cols(1) ~= 1
            tmp = vin(:,z+which_cols(1)-1);
            vin(:,z+which_cols(1)-1) = vin(:,z);
            vin(:,z) = tmp;            
        end
        pivot = vin(k,z);
        vin(:,z) = vin(:,z)/pivot;
        % Now subtract forward and back
        for t=1:size(vin,2)
            if t ~= z
                pivot = vin(k,t);
                vin(:,t) = vin(:,t) - vin(:,z)*pivot;
            end
        end
        z = z + 1;
    end
end

v2 = vin;