function ok = is_close(v1, v2)
%
% Are two values close to each other?
%
% Usage ok = is_close(v1,v2)
%
%     ok = Are v1 and v2 identical up to QLib.close_enough accuracy
%          v1, v2 are of any (equal) dimentionality
%
% Notes:
% * is_close(NaN,NaN) == 0
% * is_close(Inf,Inf) == 0
% * The function compares v1/v2-1, v2/v1-1 and v1-v2 to "close enough"
%         If for all matrix elements at least one of the above is close
%         enough, the matrices are considered close enough.
%  * A bit heavy in implementation, so don't use in tight inner loops/searches
%

global QLib;

ok = 0;
if ~is_eql(size(v1),size(v2))
    return; % Unequal dimensions
end

warning off MATLAB:divideByZero
the_ratio_1 = abs(v1./v2 - 1);
the_ratio_2 = abs(v2./v1 - 1);
warning on  MATLAB:divideByZero

the_diff  = abs(v1 - v2);

the_ratio = min(the_ratio_1,the_ratio_2);

delta = min(the_ratio, the_diff);

problem_places = [find(delta > QLib.close_enough) find(isnan(delta))];

ok = length(problem_places) == 0;
