function ok = is_close_2(v1, v2)
%
% Are two values close to each other?
% Unlike is_close, NaNs and Infs are close to themselves
%
% Usage ok = is_close(v1,v2)
%
%     ok = Are v1 and v2 identical up to QLib.close_enough accuracy
%          v1, v2 are of any (equal) dimentionality
%
% Notes:
% * is_close_2(NaN,NaN)   == 1
% * is_close_2(-Inf,-Inf) == 1
% * is_close_2(-Inf,+Inf) == 0
% * The function compares v1/v2-1, v2/v1-1 and v1-v2 to "close enough"
%         If for all matrix elements at least one of the above is close
%         enough, the matrices are considered close enough.
%  * A bit heavy in implementation, so don't use in tight inner loops/searches
%

ok = 0;

v1_nans = find(isnan(v1));
v2_nans = find(isnan(v2));
if ~isequal(v1_nans,v2_nans)
    return;
end
v1(v1_nans) = 0; v2(v2_nans) = 0;

v1_pos_infs = find(isinf(v1) & (sign(v1) ==  1));
v1_neg_infs = find(isinf(v1) & (sign(v1) == -1));
v2_pos_infs = find(isinf(v2) & (sign(v2) ==  1));
v2_neg_infs = find(isinf(v2) & (sign(v2) == -1));
if (~isequal(v1_pos_infs,v2_pos_infs)) || (~isequal(v1_neg_infs,v2_neg_infs))
    return;
end
v1(v1_pos_infs) = 0; v1(v1_neg_infs) = 0;
v2(v2_pos_infs) = 0; v2(v2_neg_infs) = 0;


ok = is_close(v1,v2);
