function [V,J2] = jordan2(a)
% 
% Jordan decomposition, returning the list of blocks (eigenvalues) as three-column matrix
%
% Usage: [V,J2] = jordan2(a)
%     a   The matrix to process     
%     J2  Three columns, one line per jordan block 
%         1: The generalized eigenvalue
%         2: The size of the jordna block (algebraic multiplicity)
%         3: The starting column of the generalized eigenvectors for this block
%     V   The eigenvectors
%
% Note: Makes use of JordanFix. In case the call fails, V and J2 will be all NaNs.
%

if nargout == 1
    V = jordanFix(a);
    return;
end

[V,J] = jordanFix(a);

J2 = [];
k = 1;
while k <= length(J)
    blocksize = 1;
    while (k < length(J)) && (J(k,k+1) == 1)
        k = k + 1;
        blocksize = blocksize + 1;
    end
    % We're now standing on the last member of the block
    J2(end+1,1) = J(k,k);
    J2(end,2)   = blocksize;
    k = k + 1;
end
J2(:,3) = cumsum(J2(:,2));