function c = smooth_ma (x, L)
%
% Compute a smoothed moving average over L elements of the vector x
%
% Usage: c = smooth_ma (x, L)
%     x   The vector containing the data
%     L   No. of elements to average
%     c   The returned smoothed x. Same length are x
%
% Moving averages on the ends of the arrays are done by duplicating the
% first & last values
%


x = to_row(x);

n = length(x);
a = [ones(1,ceil(L/2))*x(1) x ones(1,floor(L/2))*x(n)];
a = cumsum(a);
c = (a((L+1):end)-a(1:(end-L)))/L;

