function c = smooth_min (x, L)
%
% Compute a moving minimum over L elements of the vector x
%
% Usage: c = smooth_ma (x, L)
%     x   The vector containing the data
%     L   No. of elements to average
%     c   The returned minimized x. Same length are x
%
% Minimizing on the ends of the arrays are done by duplicating the
% first & last values
%

x = to_row(x);
n = length(x);
left  = -floor(L/2);
right = left + L - 1;

c = NaNs(1,n);
for center = 1:n
    rng = max(1,center+left):min(n,center+right);
    c(center) = min(x(rng));
end
