function ret = yn3_or(a1, a2)
% 
% 3-way logics: OR
%
% Usage: ret = yn3_or(a1,a2)
%
% 3-way logics, which includes a "don't know" value is useful for combining
% "witness" functions, which under certain circumstances may be able to
% answer only "yes" and "don't know", etc.
%
% Truth table is as follows:
%
%         OR       | Yes | No  | DontKnow
%         ---------+-----+-----+----------
%         Yes      | Yes | Yes | Yes
%         No       | Yes | No  | No
%         DontKnow | Yes | No  | DontKnow
%
% Yes/No/DontKnow are represented by 1/0/NaN, respectively
%

if isnan(a1) && isnan(a2)
    ret = NaN;
elseif isnan(a1)
    ret = a2;
elseif isnan(a2)
    ret = a1;
else
    ret = a1 || a2;
end
