function opt = fmin_anneal_opt(varargin)
%
% Set options for the fmin_anneal search
%
% Usage: opt = fmin_anneal_opt(opt_name_1, opt_val_1, opt_name_2, opt_val_2, ...)
%     input: Pairs of option names and their values. See details below
%     output: A structure containing a complete set of values (those set
%         and defaults for the rest).
%
% Option details: 
%     botlz: boltzmann constant
%     min_temp: stopping temp (1e-4 - 1e-10)
%     cooling_rate: annealing schedule (new_temp = old_temp * cooling_rate)
%     max_consec_rejections: number of points tested with no improvement to quit (1e1..1e5)
%     max_try: Maximum number of annealing cycles before we stop
%     max_success: Goal number of improving steps at which we may stop
%

% Default values
opt.botlz = 1;                         % boltzmann constant
opt.min_temp = 1e-8;                   % stopping temp (1e-4 - 1e-10)
opt.cooling_rate = .8;                 % annealing schedule
opt.max_consec_rejections = 500;
opt.max_try = 500;
opt.max_success = 50;

% Loop on user-supplied values
for k=1:2:length(varargin)
    if isfield(opt,varargin{k})
        opt.(varargin{k}) = varargin{k+1};
    else
        disp(' ');
        disp('fmin_anneal options (and their default values):');
        disp(opt);
        error ('Unrecognized field name: %s', varargin{k});
    end
end