function [ pure ] = aharonov(n)
%
% Return the Aharanov state
%
% INPUT
% none
%
% OUTPUT
% aha: aharanov state vector
%

if(nargin<1)
    n = 3;
end

if(n~=3)
    error('Not yet supported!');
end

b = eye(n); %standard basis

plus_terms = [1 , 2, 3;
              2 , 3, 1;
              3 , 1, 2];
minus_terms = [1, 3, 2;
               2, 1, 3;
               3, 2, 1];
           
pure = zeros(n^n,1);

for term = plus_terms'
    t1 = term(1);
    t2 = term(2);
    t3 = term(3);
    pure = pure + kron(kron(b(:,t1),b(:,t2)),b(:,t3));
end

for term = minus_terms'
    t1 = term(1);
    t2 = term(2);
    t3 = term(3);
    pure = pure - kron(kron(b(:,t1),b(:,t2)),b(:,t3));
end

pure = pure * (1/sqrt(6));

end

