function [ z,z0 ] = chsh( n,m,anti )
%
% Return the chained CHSH Bell inequality [1,2].
% [1]	S. L. Braunstein and C. M. Caves, ?Wringing out better Bell
% inequalities,? Annals of Physics, vol. 202, no. 1, pp. 22?56, 1990.
% [2]	L. Hardy, ?A new way to obtain Bell inequalities,? Phys Lett A,
% vol. 161, no. 1, pp. 21?25, 1991.
%

if nargin < 3
    anti = false;
end

if (m~=2)
    error('Not supported for m~=2, yet...');
end

cor = [0, 1; 1, 0];
a_cor = [1, 0; 0, 1];

if anti
    [cor,a_cor] = swap(cor,a_cor);
end

Z = zeros(n*m,n*m);

for i = 1:n
    for j = 1:n
        
        idx_a = i*m-1:i*m;
        idx_b = j*m-1:j*m;
        
        if (i == n) && (j == n)
            Z(idx_a,idx_b) = a_cor;
        else
            Z(idx_a,idx_b) = cor;
        end
        
    end
end

z = Z(:);
z0 = n^2 - 1;

end

