function M = h3_M( dm )
% Calculate Horodecki family's condition for violating Bell inequality
% 
% If M > 1, the Bell inequality is violated (see [1]).
% 
% Usage: M = h3_M(dm)
%   dm - density matrix
%
% Reference:
%   [1]	R. Horodecki, P. Horodecki, and M. Horodecki, "Violating Bell
%   inequality by mixed states: necessary and sufficient condition," Phys Lett A, vol. 200, no. 5, pp. 340?344, 1995.



% Pauli matrices
% sigma = zeros(2,2,3);
% sigma(:,:,1) = [0  1; 1  0];
% sigma(:,:,2) = [0 -1i; 1i  0];
% sigma(:,:,3) = [1  0; 0 -1];
% 
% % calculate T matrix
% T = zeros(3,3);
% for m = 1:3
%     for n = 1:3
%         s = kron(sigma(:,:,n),sigma(:,:,m));
%         T(n,m) = trace(dm*s);
%     end
% end

T = pauli_representation_T(dm);

% sum of two largest eigenvalues of T*T'
opts.disp=0; % disable output of eigs
M = sum(eigs(T*T',2,'lm',opts));

end

