function [ p ] = q2p( rho, MA, MB, n, m )
%
% calculate probabilistic behaviour for Bell-type experiment
%
% INPUT
% rho - density matrix
% MA - cell(d,d,m,n) set of local POVMs on A
% MB - cell(d,d,m,n) set of local POVMs on B
% n: number of possible measurement settings on both sides
% m: number of possible outcomes per measurement
 

S = zeros(n*m,n*m);
da = size(MA,1);
db = size(MB,1);

% go over all measurement setups
for i = 1:n
    for j = 1:n
        
        % go over all possible measurement outcomes
        for k = 1:m
            for l = 1:m
                op = kron(MA(:,:,k,i),eye(db)) * kron( eye(da),MB(:,:,l,j) );
                S( (i-1)*m + k, (j-1)*m + l ) = trace(op * rho);
            end
        end
    end
end

p = reshape(S,n*n*m*m,1);

end

