function [ t,G ] = state_bound_sdp( rho,W )
%
% Do the SDP thingy...
%
% INPUT
% rho: density operator of state
% W: Bell inequality
%
% OUTPUT
% t: maximal value
% G: SDP variable (Gramm-Matrix)
%

n = size(W,1);

% calculate max and min eigenvalue of T*T'
T = pauli_representation_T(rho);
evs = eigs(T*T');
e_u = max(evs);
e_l = min(evs);

% set upper and lower bounds
b_u = ones(n,1);
b_l = ones(n,1);

b_u((n/2)+1:n) = e_u;
b_l((n/2)+1:n) = e_l;


% setup and solve sdp
cvx_begin sdp
    variable G(n,n) symmetric;
    maximize( trace(G*W) );
    subject to
        G >= 0;
        diag(G) <= b_u;
        diag(G) >= b_l;
cvx_end

t = cvx_optval;

end

