%
% Various methods of doing quantum stuff with semidefinite programming. 
% 
% [1]	S. Wehner, "Tsirelson bounds for generalized 
%           Clauser-Horne-Shimony-Holt inequalities," arXiv.org, vol. quant-ph. 11-Oct.-2005.
% [2] Daniela Frauchiger, "SDP in Quantum Information", private communication
% [3] R. Horodecki, P. Horodecki, and M. Horodecki, ?Violating Bell
%       inequality by mixed states: necessary and sufficient condition,? Phys Lett A, vol. 200, no. 5, pp. 340?344, 1995.
% 
% 

%% Tsirelson bound by SDP (a la Wehner [1])

% CHSH inequality (for expectations)
W = 0.5 *  [0, 0, 1, 1;
            0, 0, 1, -1;
            1, 1, 0, 0;
            1, -1, 0, 0];

[t,G] = tsirelson_bound_sdp(W)


%% Use method as described in [2] (with some modifications)

% load a bipartite (4d) state to rho before using this.

% CHSH again
W = 0.5 *  [0, 0, 1, 1;
            0, 0, 1, -1;
            1, 1, 0, 0;
            1, -1, 0, 0];
        
[t,G] = state_bound_sdp(rho,W);

% compare with h^3 method (for CHSH), see [3] or file qm/h3_M.m
t2 = 2 * sqrt(h3_M(rho));

fprintf('Value with SDP: %.9f\n', t);
fprintf('Value with H^3: %.9f\n', t2);

