%% setup n and m

% number of measurement settings per party
n = 5;

% number of outcomes per measurement
m = 2;

% use zero constraints?
zero_constraints = false;

%% Generate the local deterministic strategies, set n,m before using this
disp('Generating local deterministic behaviours')
tic
A_lds = local_deterministic_strategies(n,m);
toc

%% load the bipartite trace of the W-State
W = pure2dm(W101);

% trace out one subsystem
rho = partial_trace(W,[1,1,0]);
clear('W');

%% Measurement in standard basis

M = standard_basis_povm(n,m);

p = q2p(rho,M,M,n,m);
clear('M');

%display p in readable form
disp('The behaviour:');
disp(reshape(p,n*m,n*m));

%% sample points around p in ns directions 

k = 20; % number of samples to collect
block_size = 1e3; % random vectors are computed in block, specifiy block size
epsilon = 1e-5 * n^2;

cont_on_out = false; % continue if outside point is found?
t_max = 1e6; % maximum number of tries
tol = 1e-10; % tolerance for zero checks

if (zero_constraints)
    % use zero constrained basis and reduced set of LDS
    zidx = find(p==0);
    B = ns_basis(n,m,zidx);
    %also you may use a restricted set of LDS
    ridx = find(sum(A_lds(zidx,:))==0);
    A = A_lds(:,ridx);
else
    % sample basis (NS basis)
    B = ns_basis(n,m);
    A = A_lds;
end

tic
[ P_inside,P_outside,P_dunno ] = sample(p,A,B,k,epsilon,block_size,cont_on_out,tol,t_max);
toc