%
% This files allows you to load the density operator of certain interesting
% quantum states to the variable rho.
%

%% load the bipartite trace of the W-State
W = pure2dm(W101);

% trace out one subsystem
rho = partial_trace(W,[1,1,0]);
clear('W');

%% load the trace of an W-like-State (i.e. c * |Psi+> + (1-c)*|00> )
% Note: for c = 2/3 this is same as loading the W-State. For c = 1 this is
% equivalent to loading the singlet |Psi+>.

% define c here
c = 2/3;

rho = W_trace(QLib.Bell.psi_plus,c);

%% Singlet: |Phi+>
rho = pure2dm(QLib.Bell.phi_plus);

%% Singlet: |Phi->
rho = pure2dm(QLib.Bell.phi_minus);

%% Singlet: |Psi+>
rho = pure2dm(QLib.Bell.psi_plus);

%% Singlet: |Psi->
rho = pure2dm(QLib.Bell.psi_minus);

%% Fully mixed state
rho = 1/4 * eye(4);

%% load the Aharonov state
rho = partial_trace_pure(aharonov,[0,1,1],[3,3,3]);

%% load the state |100> + |010> + |001> + |122> + |212> + |221>

% standard basis
b = eye(3);

% note 0 -> 1, 1 -> 2, 2 -> 3 (matlab starts indexing at 1)
M = (1/sqrt(6)) * ...
    (kron(b(:,2),kron(b(:,1),b(:,1))) + ...
    kron(b(:,1),kron(b(:,2),b(:,1))) + ...
    kron(b(:,1),kron(b(:,1),b(:,2))) + ...
    kron(b(:,2),kron(b(:,3),b(:,3))) + ...
    kron(b(:,3),kron(b(:,2),b(:,3))) + ...
    kron(b(:,3),kron(b(:,3),b(:,1))) );

rho = partial_trace_pure(M,[0,1,1],[3,3,3]);

